package com.zoniot.ccrc.controller.system;

import com.zoniot.ccrc.commom.model.AjaxMessage;
import com.zoniot.ccrc.commom.model.Pagination;
import com.zoniot.ccrc.commom.model.ResultStatus;
import com.zoniot.ccrc.dto.DeleteUserDto;
import com.zoniot.ccrc.dto.UserDto;
import com.zoniot.ccrc.dto.UserRoleDto;
import com.zoniot.ccrc.entity.Role;
import com.zoniot.ccrc.service.RoleService;
import com.zoniot.ccrc.service.UserService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.stereotype.Controller;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@Controller
@ResponseBody
@RequestMapping("system/user")
@Api(description = "用户管理")
@Validated
public class UserManageController {

    @Autowired
    private UserService userService;
    @Autowired
    private RoleService roleService;


    @GetMapping("getRoleList")
    @ApiOperation(value = "获取站点角色列表")
    public AjaxMessage<List<Role>> getRoleList(
    ) {
        List<Role> list = roleService.getSiteRoleList();
        return new AjaxMessage<>(ResultStatus.OK, list);
    }

    @GetMapping("userList")
    @PreAuthorize("hasAuthority('sys:user:query')")
    @ApiOperation(value = "获取用户分页", notes = "权限：sys:user:query")
    public AjaxMessage<Pagination<UserRoleDto>> getUserList(
            @ApiParam(value = "用户名", required = false) @RequestParam(required = false) String username,
            @ApiParam(value = "姓名", required = false) @RequestParam(required = false) String name,
            @ApiParam(value = "手机号", required = false) @RequestParam(required = false) String mobilePhone,
            @ApiParam(value = "机构id", required = false) @RequestParam(required = false) Integer organId,
            @ApiParam(value = "角色id", required = false) @RequestParam(required = false) Integer roleId,
            @ApiParam(value = "数据项id", required = false) @RequestParam(required = false) Integer programId,
            @ApiParam(value = "页数,非必传，默认第一页", required = false, defaultValue = "1") @RequestParam(required = false, defaultValue = "1") int pageNum,
            @ApiParam(value = "条数，非必传，默认15条", required = false, defaultValue = "15") @RequestParam(required = false, defaultValue = "15") int pageSize
    ) {
        Pagination<UserRoleDto> pageInfo = userService.getUserList(StringUtils.trim(username), StringUtils.trim(name), StringUtils.trim(mobilePhone), organId, roleId, programId, pageNum, pageSize);
        return new AjaxMessage<>(ResultStatus.OK, pageInfo);
    }

    @GetMapping("getAllUserList")
    @ApiOperation(value = "获取用户列表", notes = "权限：sys:user:query")
    public AjaxMessage<List<UserDto>> getAllList(
            @ApiParam(value = "机构id", required = false) @RequestParam(required = false) Integer organId,
            @ApiParam(value = "任务ID", required = false) @RequestParam(required = false) String taskId
    ) {
        List<UserDto> list = userService.getAllUserList(organId, taskId);
        return new AjaxMessage<>(ResultStatus.OK, list);
    }

    @PostMapping("add")
    @PreAuthorize("hasAuthority('sys:user:add')")
    @ApiOperation(value = "添加用户", notes = "权限：sys:user:add")
    public AjaxMessage addUser(
            @ApiParam(value = "用户名", required = true) @RequestParam(required = true) String username,
            @ApiParam(value = "真实姓名", required = false) @RequestParam(required = false) String name,
            @ApiParam(value = "手机号码", required = true) @RequestParam(required = true) String mobilePhone,
            @ApiParam(value = "角色id", required = false) @RequestParam(required = false) Integer roleId,
            @ApiParam(value = "机构id", required = false) @RequestParam(required = false) Integer orgId
    ) {
        userService.addUser(StringUtils.trim(username), StringUtils.trim(name), StringUtils.trim(mobilePhone), roleId,orgId);
        return new AjaxMessage(ResultStatus.OK);
    }

    @PutMapping("edit")
    @ApiOperation(value = "编辑用户", notes = "权限：sys:user:edit")
    @PreAuthorize("hasAuthority('sys:user:edit')")
    public AjaxMessage editUser(
            @ApiParam(value = "用户id", required = true) @RequestParam(required = true) Integer id,
            @ApiParam(value = "真实姓名", required = false) @RequestParam(required = false) String name,
            @ApiParam(value = "手机号码", required = true) @RequestParam(required = true) String mobilePhone,
            @ApiParam(value = "角色id", required = false) @RequestParam(required = false) Integer roleId,
            @ApiParam(value = "机构id", required = false) @RequestParam(required = false) Integer orgId
    ) {

        userService.editUser(id, StringUtils.trim(name), StringUtils.trim(mobilePhone), roleId,orgId);
        return new AjaxMessage(ResultStatus.OK);
    }

    @DeleteMapping("/del")
    @PreAuthorize("hasAuthority('sys:user:del')")
    @ApiOperation(value = "删除用户", notes = "权限：sys:user:del")
    public AjaxMessage delUser(
            @ApiParam(value = "用户id", required = true) @RequestParam(required = true) Integer id
    ) {

        userService.delectUser(id);
        return new AjaxMessage(ResultStatus.OK);
    }

    @DeleteMapping("/batchDel")
    @PreAuthorize("hasAuthority('sys:user:del')")
    @ApiOperation(value = "批量删除用户", notes = "权限：sys:user:del")
    public AjaxMessage batchDel(
            @ApiParam(value = "用户id", required = true) @RequestBody(required = true) DeleteUserDto deleteUserDto
    ) {
        userService.batchDelectUser(deleteUserDto);
        return new AjaxMessage(ResultStatus.OK);
    }

    @GetMapping("deleteQuery")
    @ApiOperation(value = "删除查询", notes = "返回数组为空既可删除，否则返回不可删除的用户")
    public AjaxMessage<List<UserDto>> deleteQuery(
            @ApiParam(value = "用户id，多个英文逗号隔开", required = true) @RequestParam(required = true) List<Integer> userIds
    ) {
        List<UserDto> list = userService.deleteQuery(userIds);
        return new AjaxMessage<>(ResultStatus.OK, list);
    }
    @PostMapping("/updateStatus")
    @ApiOperation(value = "启用/禁用用户")
    public AjaxMessage updateStatus(
            @ApiParam(value = "用户id", required = true) @RequestParam(required = true) Integer id
    ) {
        userService.updateStatus(id);
        return new AjaxMessage(ResultStatus.OK);
    }

}
